@@ -1,27 +1,13 @@
-/**
- * klinkdialog
- *
- * Copyright 2008  Stephen Kelly <steveire@gmailcom>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
- */
+/*
+    klinkdialog
+    SPDX-FileCopyrightText: 2008 Stephen Kelly <steveire@gmailcom>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "klinkdialog_p.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QDialogButtonBox>
 #include <QLabel>
@@ -52,8 +38,7 @@ KLinkDialog::KLinkDialog(QWidget *parent)
     setWindowTitle(i18n("Manage Link"));
     setModal(true);
 
-    QVBoxLayout *layout = new QVBoxLayout;
-    setLayout(layout);
+    QVBoxLayout *layout = new QVBoxLayout(this);
 
     QGridLayout *grid = new QGridLayout;
 
