@@ -1,28 +1,15 @@
 /*
-    Copyright (C) 2001, S.R.Haque <srhaque@iee.org>.
-    Copyright (C) 2002, David Faure <david@mandrakesoft.com>
     This file is part of the KDE project
+    SPDX-FileCopyrightText: 2001 S.R. Haque <srhaque@iee.org>.
+    SPDX-FileCopyrightText: 2002 David Faure <david@mandrakesoft.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LGPL-2.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kfinddialog.h"
 #include "kfinddialog_p.h"
 
 #include "kfind.h"
-#include "kregexpeditorinterface.h"
 
 #include <QCheckBox>
 #include <QDialogButtonBox>
@@ -31,14 +18,13 @@
 #include <QLineEdit>
 #include <QMenu>
 #include <QPushButton>
-#include <QtCore/QRegExp>
+#include <QRegularExpression>
 #include <QGridLayout>
 
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kplugintrader.h>
-#include <kguiitem.h>
-#include <khistorycombobox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KGuiItem>
+#include <KHistoryComboBox>
 
 #include <assert.h>
 
@@ -74,12 +60,8 @@ QStringList KFindDialog::findHistory() const
 
 void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_findStrings, bool hasSelection)
 {
-    QVBoxLayout *topLayout;
-    QGridLayout *optionsLayout;
-
     // Create common parts of dialog.
-    topLayout = new QVBoxLayout;
-    q->setLayout(topLayout);
+    QVBoxLayout *topLayout = new QVBoxLayout(q);
 
     findGrp = new QGroupBox(i18nc("@title:group", "Find"), q);
     findLayout = new QGridLayout(findGrp);
@@ -116,7 +98,7 @@ void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_
     topLayout->addWidget(replaceGrp);
 
     QGroupBox *optionGrp = new QGroupBox(i18n("Options"), q);
-    optionsLayout = new QGridLayout(optionGrp);
+    QGridLayout *optionsLayout = new QGridLayout(optionGrp);
 
     caseSensitive = new QCheckBox(i18n("C&ase sensitive"), optionGrp);
     wholeWordsOnly = new QCheckBox(i18n("&Whole words only"), optionGrp);
@@ -266,13 +248,15 @@ void KFindDialog::showEvent(QShowEvent *e)
         //maintain a user-friendly tab order
         if (d->findExtension) {
             QWidget *prev = d->regExpItem;
-            Q_FOREACH (QWidget *child, d->findExtension->findChildren<QWidget *>()) {
+            const auto children = d->findExtension->findChildren<QWidget *>();
+            for (QWidget *child : children) {
                 setTabOrder(prev, child);
                 prev = child;
             }
             setTabOrder(prev, d->replace);
         }
     }
+    d->find->setFocus();
     QDialog::showEvent(e);
 }
 
@@ -316,7 +300,7 @@ void KFindDialog::setPattern(const QString &pattern)
 
 void KFindDialog::setFindHistory(const QStringList &strings)
 {
-    if (strings.count() > 0) {
+    if (!strings.isEmpty()) {
         d->find->setHistoryItems(strings, true);
         d->find->lineEdit()->setText(strings.first());
         d->find->lineEdit()->selectAll();
@@ -427,93 +411,74 @@ void KFindDialog::setOptions(long options)
 // compose a regular expression search pattern.
 void KFindDialog::KFindDialogPrivate::_k_showPatterns()
 {
-    if (!regexpDialogQueryDone) {
-        regexpDialog = KPluginTrader::createInstanceFromQuery<QDialog>(QStringLiteral("kregexpeditor"),
-                       QStringLiteral("KRegExpEditor/KRegExpEditor"),
-                       QString(),
-                       nullptr,
-                       q);
-        regexpDialogQueryDone = true;
+    typedef struct {
+        const char *description;
+        const char *regExp;
+        int cursorAdjustment;
+    } Term;
+    static const Term items[] = {
+        { I18N_NOOP("Any Character"),                 ".",        0 },
+        { I18N_NOOP("Start of Line"),                 "^",        0 },
+        { I18N_NOOP("End of Line"),                   "$",        0 },
+        { I18N_NOOP("Set of Characters"),             "[]",       -1 },
+        { I18N_NOOP("Repeats, Zero or More Times"),   "*",        0 },
+        { I18N_NOOP("Repeats, One or More Times"),    "+",        0 },
+        { I18N_NOOP("Optional"),                      "?",        0 },
+        { I18N_NOOP("Escape"),                        "\\",       0 },
+        { I18N_NOOP("TAB"),                           "\\t",      0 },
+        { I18N_NOOP("Newline"),                       "\\n",      0 },
+        { I18N_NOOP("Carriage Return"),               "\\r",      0 },
+        { I18N_NOOP("White Space"),                   "\\s",      0 },
+        { I18N_NOOP("Digit"),                         "\\d",      0 },
+    };
+
+    class RegExpAction : public QAction
+    {
+    public:
+        RegExpAction(QObject *parent, const QString &text, const QString &regExp, int cursor)
+            : QAction(text, parent), mText(text), mRegExp(regExp), mCursor(cursor)
+        {
+        }
+
+        QString text() const
+        {
+            return mText;
+        }
+        QString regExp() const
+        {
+            return mRegExp;
+        }
+        int cursor() const
+        {
+            return mCursor;
+        }
+
+    private:
+        QString mText;
+        QString mRegExp;
+        int mCursor;
+    };
+
+
+    // Populate the popup menu.
+    if (!patterns) {
+        patterns = new QMenu(q);
+        for (const Term &item : items) {
+            patterns->addAction(new RegExpAction(patterns, i18n(item.description),
+                                                    QLatin1String(item.regExp),
+                                                    item.cursorAdjustment));
+        }
     }
 
-    if (regexpDialog) {
-        KRegExpEditorInterface *iface = qobject_cast<KRegExpEditorInterface *>(regexpDialog);
-        assert(iface);
+    // Insert the selection into the edit control.
+    QAction *action = patterns->exec(regExpItem->mapToGlobal(regExpItem->rect().bottomLeft()));
+    if (action) {
+        RegExpAction *regExpAction = static_cast<RegExpAction *>(action);
+        if (regExpAction) {
+            QLineEdit *editor = find->lineEdit();
 
-        iface->setRegExp(q->pattern());
-        if (regexpDialog->exec() == QDialog::Accepted) {
-            q->setPattern(iface->regExp());
-        }
-    } else { // No complete regexp-editor available, bring up the old popupmenu
-        typedef struct {
-            const char *description;
-            const char *regExp;
-            int cursorAdjustment;
-        } term;
-        static const term items[] = {
-            { I18N_NOOP("Any Character"),                 ".",        0 },
-            { I18N_NOOP("Start of Line"),                 "^",        0 },
-            { I18N_NOOP("End of Line"),                   "$",        0 },
-            { I18N_NOOP("Set of Characters"),             "[]",       -1 },
-            { I18N_NOOP("Repeats, Zero or More Times"),   "*",        0 },
-            { I18N_NOOP("Repeats, One or More Times"),    "+",        0 },
-            { I18N_NOOP("Optional"),                      "?",        0 },
-            { I18N_NOOP("Escape"),                        "\\",       0 },
-            { I18N_NOOP("TAB"),                           "\\t",      0 },
-            { I18N_NOOP("Newline"),                       "\\n",      0 },
-            { I18N_NOOP("Carriage Return"),               "\\r",      0 },
-            { I18N_NOOP("White Space"),                   "\\s",      0 },
-            { I18N_NOOP("Digit"),                         "\\d",      0 },
-        };
-
-        class RegExpAction : public QAction
-        {
-        public:
-            RegExpAction(QObject *parent, const QString &text, const QString &regExp, int cursor)
-                : QAction(text, parent), mText(text), mRegExp(regExp), mCursor(cursor)
-            {
-            }
-
-            QString text() const
-            {
-                return mText;
-            }
-            QString regExp() const
-            {
-                return mRegExp;
-            }
-            int cursor() const
-            {
-                return mCursor;
-            }
-
-        private:
-            QString mText;
-            QString mRegExp;
-            int mCursor;
-        };
-
-
-        // Populate the popup menu.
-        if (!patterns) {
-            patterns = new QMenu(q);
-            for (int i = 0; (unsigned)i < sizeof(items) / sizeof(items[0]); i++) {
-                patterns->addAction(new RegExpAction(patterns, i18n(items[i].description),
-                                                     QLatin1String(items[i].regExp),
-                                                     items[i].cursorAdjustment));
-            }
-        }
-
-        // Insert the selection into the edit control.
-        QAction *action = patterns->exec(regExpItem->mapToGlobal(regExpItem->rect().bottomLeft()));
-        if (action) {
-            RegExpAction *regExpAction = static_cast<RegExpAction *>(action);
-            if (regExpAction) {
-                QLineEdit *editor = find->lineEdit();
-
-                editor->insert(regExpAction->regExp());
-                editor->setCursorPosition(editor->cursorPosition() + regExpAction->cursor());
-            }
+            editor->insert(regExpAction->regExp());
+            editor->setCursorPosition(editor->cursorPosition() + regExpAction->cursor());
         }
     }
 }
@@ -566,10 +531,9 @@ void KFindDialog::KFindDialogPrivate::_k_slotPlaceholdersAboutToShow()
     placeholders->clear();
     placeholders->addAction(new PlaceHolderAction(placeholders, i18n("Complete Match"), 0));
 
-    QRegExp r(q->pattern());
-    uint n = r.captureCount();
-    for (uint i = 0; i < n; i++) {
-        placeholders->addAction(new PlaceHolderAction(placeholders, i18n("Captured Text (%1)",  i + 1), i + 1));
+    const int n = QRegularExpression(q->pattern()).captureCount();
+    for (int i = 1; i <= n; ++i) {
+        placeholders->addAction(new PlaceHolderAction(placeholders, i18n("Captured Text (%1)",  i), i));
     }
 }
 
@@ -583,10 +547,8 @@ void KFindDialog::KFindDialogPrivate::_k_slotOk()
 
     if (regExp->isChecked()) {
         // Check for a valid regular expression.
-        QRegExp _regExp(q->pattern());
-
-        if (!_regExp.isValid()) {
-            KMessageBox::error(q, i18n("Invalid regular expression."));
+        if (!QRegularExpression(q->pattern()).isValid()) {
+            KMessageBox::error(q, i18n("Invalid PCRE pattern syntax."));
             return;
         }
     }
