@@ -1,21 +1,9 @@
 /*
-    Copyright (C) 2001, S.R.Haque <srhaque@iee.org>.
-    Copyright (C) 2002, David Faure <david@mandrakesoft.com>
     This file is part of the KDE project
+    SPDX-FileCopyrightText: 2001 S.R. Haque <srhaque@iee.org>.
+    SPDX-FileCopyrightText: 2002 David Faure <david@mandrakesoft.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LGPL-2.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kreplace.h"
@@ -23,11 +11,14 @@
 #include "kfind_p.h"
 #include "kreplacedialog.h"
 
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
+#include <QRegExp>
+#endif
+
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <QRegExp>
 #include <QRegularExpression>
 
 #include <KLocalizedString>
@@ -60,8 +51,7 @@ KReplaceNextDialog::KReplaceNextDialog(QWidget *parent)
     setModal(false);
     setWindowTitle(i18n("Replace"));
 
-    QVBoxLayout *layout = new QVBoxLayout;
-    setLayout(layout);
+    QVBoxLayout *layout = new QVBoxLayout(this);
 
     m_mainLabel = new QLabel(this);
     layout->addWidget(m_mainLabel);
