@@ -1,25 +1,11 @@
 /*
- * krichtextedit
- *
- * Copyright 2007 Laurent Montel <montel@kde.org>
- * Copyright 2008 Thomas McGuire <thomas.mcguire@gmx.net>
- * Copyright 2008 Stephen Kelly  <steveire@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
- */
+    krichtextedit
+    SPDX-FileCopyrightText: 2007 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2008 Thomas McGuire <thomas.mcguire@gmx.net>
+    SPDX-FileCopyrightText: 2008 Stephen Kelly <steveire@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "krichtextedit.h"
 
@@ -28,10 +14,11 @@
 #include "klinkdialog_p.h"
 
 // kdelibs includes
-#include <kcursor.h>
-#include <kcolorscheme.h>
+#include <KCursor>
+#include <KColorScheme>
 
 // Qt includes
+#include <QRegularExpression>
 
 /**
   Private class that helps to provide binary compatibility between releases.
@@ -42,8 +29,7 @@ class KRichTextEditPrivate : public QObject
 {
 public:
     explicit KRichTextEditPrivate(KRichTextEdit *parent)
-        : q(parent),
-          mMode(KRichTextEdit::Plain)
+        : q(parent)
     {
         nestedListHelper = new NestedListHelper(q);
     }
@@ -75,8 +61,8 @@ public:
 
     // Data members
 
-    KRichTextEdit *q;
-    KRichTextEdit::Mode mMode;
+    KRichTextEdit *const q;
+    KRichTextEdit::Mode mMode = KRichTextEdit::Plain;
 
     NestedListHelper *nestedListHelper;
 
@@ -149,13 +135,13 @@ void KRichTextEdit::setListStyle(int _styleIndex)
 
 void KRichTextEdit::indentListMore()
 {
-    d->nestedListHelper->handleOnIndentMore();
+    d->nestedListHelper->changeIndent(+1);
     d->activateRichText();
 }
 
 void KRichTextEdit::indentListLess()
 {
-    d->nestedListHelper->handleOnIndentLess();
+    d->nestedListHelper->changeIndent(-1);
 }
 
 void KRichTextEdit::insertHorizontalRule()
@@ -167,9 +153,9 @@ void KRichTextEdit::insertHorizontalRule()
     cursor.beginEditBlock();
     cursor.insertHtml(QStringLiteral("<hr>"));
     cursor.insertBlock(bf, cf);
+    cursor.endEditBlock();
     setTextCursor(cursor);
     d->activateRichText();
-    cursor.endEditBlock();
 }
 
 void KRichTextEdit::alignLeft()
@@ -337,6 +323,48 @@ void KRichTextEdit::setTextSubScript(bool subscript)
     d->activateRichText();
 }
 
+void KRichTextEdit::setHeadingLevel(int level)
+{
+    const int boundedLevel = qBound(0, 6, level);
+    // Apparently, 5 is maximum for FontSizeAdjustment; otherwise level=1 and
+    // level=2 look the same
+    const int sizeAdjustment = boundedLevel > 0 ? 5 - boundedLevel: 0;
+
+    QTextCursor cursor = textCursor();
+    cursor.beginEditBlock();
+
+    QTextBlockFormat blkfmt;
+    blkfmt.setHeadingLevel(boundedLevel);
+    cursor.mergeBlockFormat(blkfmt);
+
+    QTextCharFormat chrfmt;
+    chrfmt.setFontWeight(boundedLevel > 0 ? QFont::Bold : QFont::Normal);
+    chrfmt.setProperty(QTextFormat::FontSizeAdjustment, sizeAdjustment);
+    // Applying style to the current line or selection
+    QTextCursor selectCursor = cursor;
+    if (selectCursor.hasSelection()) {
+        QTextCursor top = selectCursor;
+        top.setPosition(qMin(top.anchor(), top.position()));
+        top.movePosition(QTextCursor::StartOfBlock);
+
+        QTextCursor bottom = selectCursor;
+        bottom.setPosition(qMax(bottom.anchor(), bottom.position()));
+        bottom.movePosition(QTextCursor::EndOfBlock);
+
+        selectCursor.setPosition(top.position(), QTextCursor::MoveAnchor);
+        selectCursor.setPosition(bottom.position(), QTextCursor::KeepAnchor);
+    } else {
+        selectCursor.select(QTextCursor::BlockUnderCursor);
+    }
+    selectCursor.mergeCharFormat(chrfmt);
+
+    cursor.mergeBlockCharFormat(chrfmt);
+    cursor.endEditBlock();
+    setTextCursor(cursor);
+    setFocus();
+    d->activateRichText();
+}
+
 void KRichTextEdit::enableRichTextMode()
 {
     d->activateRichText();
@@ -490,18 +518,43 @@ void KRichTextEdit::keyPressEvent(QKeyEvent *event)
 {
     bool handled = false;
     if (textCursor().currentList()) {
-        // handled is False if the key press event was not handled or not completely
-        // handled by the Helper class.
-        handled = d->nestedListHelper->handleBeforeKeyPressEvent(event);
+        handled = d->nestedListHelper->handleKeyPressEvent(event);
+    }
+
+    // If a line was merged with previous (next) one, with different heading level,
+    // the style should also be adjusted accordingly (i.e. merged)
+    if ((event->key() == Qt::Key_Backspace && textCursor().atBlockStart() &&
+            (textCursor().blockFormat().headingLevel() != textCursor().block().previous().blockFormat().headingLevel()))
+     || (event->key() == Qt::Key_Delete && textCursor().atBlockEnd() &&
+            (textCursor().blockFormat().headingLevel() != textCursor().block().next().blockFormat().headingLevel())))
+    {
+        QTextCursor cursor = textCursor();
+        cursor.beginEditBlock();
+        if (event->key() == Qt::Key_Delete) {
+            cursor.deleteChar();
+        } else {
+            cursor.deletePreviousChar();
+        }
+        setHeadingLevel(cursor.blockFormat().headingLevel());
+        cursor.endEditBlock();
+        handled = true;
     }
 
     if (!handled) {
         KTextEdit::keyPressEvent(event);
     }
 
-    if (textCursor().currentList()) {
-        d->nestedListHelper->handleAfterKeyPressEvent(event);
+    // Match the behavior of office suites: newline after header switches to normal text
+    if ((event->key() == Qt::Key_Return)
+            && (textCursor().blockFormat().headingLevel() > 0)
+            && (textCursor().atBlockEnd()))
+    {
+        // it should be undoable together with actual "return" keypress
+        textCursor().joinPreviousEditBlock();
+        setHeadingLevel(0);
+        textCursor().endEditBlock();
     }
+
     emit cursorPositionChanged();
 }
 
@@ -539,7 +592,7 @@ QString KRichTextEdit::toCleanHtml() const
     // Qt inserts various style properties based on the current mode of the editor (underline,
     // bold, etc), but only empty paragraphs *also* have qt-paragraph-type set to 'empty'.
     static const QString EMPTYLINEREGEX = QStringLiteral(
-            "<p style=\"-qt-paragraph-type:empty;(.*)</p>");
+            "<p style=\"-qt-paragraph-type:empty;(.*?)</p>");
 
     static const QString OLLISTPATTERNQT = QStringLiteral(
             "<ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
@@ -557,20 +610,8 @@ QString KRichTextEdit::toCleanHtml() const
     // a non-existing line.
     // Although we can simply remove the margin-top style property, we still get unwanted results
     // if you have three or more empty lines. It's best to replace empty <p> elements with <p>&nbsp;</p>.
-
-    QRegExp emptyLineFinder(EMPTYLINEREGEX);
-    emptyLineFinder.setMinimal(true);
-
-    // find the first occurrence
-    int offset = emptyLineFinder.indexIn(result, 0);
-    while (offset != -1) {
-        // replace all the matching text with the new line text
-        result.replace(offset, emptyLineFinder.matchedLength(), EMPTYLINEHTML);
-        // advance the search offset to just beyond the last replace
-        offset += EMPTYLINEHTML.length();
-        // find the next occurrence
-        offset = emptyLineFinder.indexIn(result, offset);
-    }
+    // replace all occurrences with the new line text
+    result.replace(QRegularExpression(EMPTYLINEREGEX), EMPTYLINEHTML);
 
     // fix 2a - ordered lists - MS Outlook treats margin-left:0px; as
     // a non-existing number; e.g: "1. First item" turns into "First Item"
