@@ -39,7 +39,7 @@ public:
 
     QList<QAction *> richTextActionList;
     QTextCharFormat painterFormat;
-    KRichTextWidget *q;
+    KRichTextWidget *const q;
 
     RichTextSupport richTextSupport;
 
@@ -220,7 +220,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_font_family = new KFontAction(i18nc("@action", "&Font"), this);
         d->richTextActionList.append((d->action_font_family));
         d->action_font_family->setObjectName(QStringLiteral("format_font_family"));
-        connect(d->action_font_family, SIGNAL(triggered(QString)), this, SLOT(setFontFamily(QString)));
+        connect(d->action_font_family, &KSelectAction::textTriggered, this, &KRichTextWidget::setFontFamily);
     } else {
         d->action_font_family = nullptr;
     }
@@ -243,7 +243,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_text_bold->setFont(bold);
         d->richTextActionList.append((d->action_text_bold));
         d->action_text_bold->setObjectName(QStringLiteral("format_text_bold"));
-        d->action_text_bold->setShortcut(Qt::CTRL + Qt::Key_B);
+        d->action_text_bold->setShortcut(Qt::CTRL | Qt::Key_B);
         connect(d->action_text_bold, &QAction::triggered, this, &KRichTextEdit::setTextBold);
     } else {
         d->action_text_bold = nullptr;
@@ -257,7 +257,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_text_italic->setFont(italic);
         d->richTextActionList.append((d->action_text_italic));
         d->action_text_italic->setObjectName(QStringLiteral("format_text_italic"));
-        d->action_text_italic->setShortcut(Qt::CTRL + Qt::Key_I);
+        d->action_text_italic->setShortcut(Qt::CTRL | Qt::Key_I);
         connect(d->action_text_italic, &QAction::triggered,
                 this, &KRichTextEdit::setTextItalic);
     } else {
@@ -272,7 +272,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_text_underline->setFont(underline);
         d->richTextActionList.append((d->action_text_underline));
         d->action_text_underline->setObjectName(QStringLiteral("format_text_underline"));
-        d->action_text_underline->setShortcut(Qt::CTRL + Qt::Key_U);
+        d->action_text_underline->setShortcut(Qt::CTRL | Qt::Key_U);
         connect(d->action_text_underline, &QAction::triggered,
                 this, &KRichTextEdit::setTextUnderline);
     } else {
@@ -287,7 +287,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_text_strikeout->setFont(strikeout);
         d->richTextActionList.append((d->action_text_strikeout));
         d->action_text_strikeout->setObjectName(QStringLiteral("format_text_strikeout"));
-        d->action_text_strikeout->setShortcut(Qt::CTRL + Qt::Key_L);
+        d->action_text_strikeout->setShortcut(Qt::CTRL | Qt::Key_L);
         connect(d->action_text_strikeout, &QAction::triggered,
                 this, &KRichTextEdit::setTextStrikeOut);
     } else {
@@ -384,7 +384,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->richTextActionList.append((d->action_list_style));
         d->action_list_style->setObjectName(QStringLiteral("format_list_style"));
 
-        connect(d->action_list_style, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered),
+        connect(d->action_list_style, &KSelectAction::indexTriggered,
                 this, [this](int style) {d->_k_setListStyle(style);});
         connect(d->action_list_style, SIGNAL(triggered()),
                 this, SLOT(_k_updateMiscActions()));
@@ -496,7 +496,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_heading_level->setCurrentItem(0);
         d->richTextActionList.append(d->action_heading_level);
         d->action_heading_level->setObjectName(QStringLiteral("format_heading_level"));
-        connect(d->action_heading_level, QOverload<int>::of(&KSelectAction::triggered),
+        connect(d->action_heading_level, &KSelectAction::indexTriggered,
                 this, [this](int level){ d->_k_setHeadingLevel(level); });
     } else {
         d->action_heading_level = nullptr;
